@@ -45,8 +45,12 @@ cql_translate <- function(...) {
         )
       }
     }
-    
-    rlang::new_quosure(dbplyr::partial_eval(x), rlang::get_env(x))
+
+    if (utils::packageVersion("dbplyr") <= "2.1.1") {
+      rlang::new_quosure(dbplyr::partial_eval(x, vars = character()), rlang::get_env(x))
+    } else {
+      rlang::new_quosure(dbplyr::partial_eval(x, data = dbplyr::lazy_frame()), rlang::get_env(x))
+    }
   })
   
   sql_where <- dbplyr::translate_sql_(dots, con = wfs_con, window = FALSE)
@@ -130,6 +134,10 @@ cql_agg <- dbplyr::sql_translator(
   max        = no_agg("max")
 )
 
+#' @importFrom dbplyr dbplyr_edition
+#' @export
+dbplyr_edition.wfsConnection <- function(con) 2L
+
 #' wfsConnection class
 #'
 #' @import methods
@@ -147,13 +155,13 @@ wfs_con <- structure(
 )
 
 # Custom sql_translator using cql variants defined above
-#' @keywords internal
-#' @importFrom dplyr sql_translate_env
-#' @export
 # TODO: After dbplyr 2.0 I think this will be sql_translation, with
 # generic from dbplyr rather than dplyr
-# (https://dbplyr.tidyverse.org/dev/articles/backend-2.html)
-sql_translate_env.wfsConnection <- function(conn) {
+# (https://dbplyr.tidyverse.org/dev/articles/backend-2.html): Done June 10 2022
+#' @keywords internal
+#' @importFrom dbplyr sql_translation
+#' @export
+sql_translation.wfsConnection <- function(conn) {
   dbplyr::sql_variant(
     cql_scalar,
     cql_agg,
@@ -161,24 +169,6 @@ sql_translate_env.wfsConnection <- function(conn) {
   )
 }
 
-# Make sure that identities (LHS of relations) are escaped with double quotes
-# TODO: After dbplyr 2.0 I think we can remove these and move the body into dbQuoteIdentifier
-#' @keywords internal
-#' @importFrom dplyr sql_escape_ident
-#' @export
-sql_escape_ident.wfsConnection <- function(conn, x) {
-  dbplyr::sql_quote(x, "\"")
-}
-
-# Make sure that strings (RHS of relations) are escaped with single quotes
-# TODO: After dbplyr 2.0 I think we can remove these and move the body into dbQuoteString
-#' @keywords internal
-#' @importFrom dplyr sql_escape_string
-#' @export
-sql_escape_string.wfsConnection <- function(conn, x) {
-  dbplyr::sql_quote(x, "'")
-}
-
 # Make sure that identities (LHS of relations) are escaped with double quotes
 
 #' @keywords internal
@@ -186,7 +176,8 @@ sql_escape_string.wfsConnection <- function(conn, x) {
 #' @exportMethod dbQuoteIdentifier
 #' @export
 setMethod("dbQuoteIdentifier", c("wfsConnection", "ANY"),
-          sql_escape_ident.wfsConnection)
+          function(conn, x) dbplyr::sql_quote(x, "\"")
+          )
 
 # Make sure that strings (RHS of relations) are escaped with single quotes
 
@@ -195,4 +186,5 @@ setMethod("dbQuoteIdentifier", c("wfsConnection", "ANY"),
 #' @exportMethod dbQuoteString
 #' @export
 setMethod("dbQuoteString", c("wfsConnection", "ANY"),
-          sql_escape_string.wfsConnection)
+          function(conn, x) dbplyr::sql_quote(x, "'")
+            )
